==============================================
API
==============================================

.. currentmodule:: popstock

.. autosummary::
   :toctree: api
   :template: custom-module-template.rst
   :caption: API:
   :recursive:
   
   PopulationOmegaGW

   constants
   util
